@@ -235,9 +235,15 @@ public:
     /** Returns an iterator representing the first byte of the instance. */
     const_iterator begin() const { return const_iterator(0U, getControl()); }
 
+    /** Same as `begin()`, just for compatibility with std types. */
+    const_iterator cbegin() const { return const_iterator(0U, getControl()); }
+
     /** Returns an iterator representing the end of the instance. */
     const_iterator end() const { return const_iterator(size(), getControl()); }
 
+    /** Same as `end()`, just for compatibility with std types. */
+    const_iterator cend() const { return const_iterator(size(), getControl()); }
+
     /** Returns an iterator referring to the given offset. */
     const_iterator at(Offset o) const { return begin() + o; }
 
@@ -482,6 +488,14 @@ public:
      */
     uint64_t toUInt(hilti::rt::ByteOrder byte_order) const;
 
+    /**
+     * Interprets the data as an ASCII representation of a floating point value
+     * and extracts that. The data must be in a format that `strtod` can handle.
+     *
+     * @return converted real value
+     */
+    double toReal() const;
+
     /**
      * Interprets the data as an ASCII representation of a integer value
      * representing seconds since the UNIX epoch, and extracts that.
