@@ -6,11 +6,13 @@
 #include <hilti/ast/operators/bitfield.h>
 #include <hilti/ast/operators/bool.h>
 #include <hilti/ast/operators/bytes.h>
+#include <hilti/ast/operators/common.h>
 #include <hilti/ast/operators/enum.h>
 #include <hilti/ast/operators/error.h>
 #include <hilti/ast/operators/exception.h>
 #include <hilti/ast/operators/function.h>
 #include <hilti/ast/operators/generic.h>
+#include <hilti/ast/operators/integer.h>
 #include <hilti/ast/operators/interval.h>
 #include <hilti/ast/operators/list.h>
 #include <hilti/ast/operators/map.h>
@@ -22,12 +24,10 @@
 #include <hilti/ast/operators/regexp.h>
 #include <hilti/ast/operators/result.h>
 #include <hilti/ast/operators/set.h>
-#include <hilti/ast/operators/signed-integer.h>
 #include <hilti/ast/operators/stream.h>
 #include <hilti/ast/operators/string.h>
 #include <hilti/ast/operators/struct.h>
 #include <hilti/ast/operators/time.h>
 #include <hilti/ast/operators/tuple.h>
 #include <hilti/ast/operators/union.h>
-#include <hilti/ast/operators/unsigned-integer.h>
 #include <hilti/ast/operators/vector.h>
