@@ -1,5 +1,6 @@
 // Copyright (c) 2020-2023 by the Zeek Project. See LICENSE for details.
 
+#include <spicy/ast/builder/builder.h>
 #include <spicy/compiler/driver.h>
 
 using namespace spicy;
@@ -18,6 +19,10 @@ void Driver::setSpicyCompilerOptions(const spicy::Options& options) {
     setCompilerOptions(std::move(hilti_options));
 }
 
+std::unique_ptr<hilti::Builder> Driver::createBuilder(hilti::ASTContext* ctx) const {
+    return std::make_unique<Builder>(ctx);
+}
+
 std::string Driver::hookAddCommandLineOptions() { return "Q"; }
 
 bool Driver::hookProcessCommandLineOption(int opt, const char* optarg) {
