@@ -223,9 +223,9 @@ struct Manager::WriterInfo {
     bool hook_initialized = false;
     string instantiating_filter;
 
-    telemetry::IntCounter total_writes;
+    std::shared_ptr<telemetry::Counter> total_writes;
 
-    WriterInfo(telemetry::IntCounter total_writes) : total_writes(total_writes) {}
+    WriterInfo(std::shared_ptr<telemetry::Counter> total_writes) : total_writes(std::move(total_writes)) {}
 };
 
 struct Manager::Stream {
@@ -244,7 +244,7 @@ struct Manager::Stream {
 
     bool enable_remote = false;
 
-    std::optional<telemetry::IntCounter> total_writes; // Initialized on first write.
+    std::shared_ptr<telemetry::Counter> total_writes; // Initialized on first write.
 
     // State about delayed writes for this Stream.
     detail::DelayQueue delay_queue;
@@ -418,14 +418,12 @@ void Manager::Stream::DispatchDelayExpiredTimer(double t, bool is_expire) {
 Manager::Manager()
     : plugin::ComponentManager<logging::Component>("Log", "Writer"),
       total_log_stream_writes_family(telemetry_mgr->CounterFamily("zeek", "log-stream-writes", {"module", "stream"},
-                                                                  "Total number of log writes for the given stream.",
-                                                                  "1", true)),
+                                                                  "Total number of log writes for the given stream.")),
       total_log_writer_writes_family(
           telemetry_mgr
               ->CounterFamily("zeek", "log-writer-writes", {"writer", "module", "stream", "filter-name", "path"},
                               "Total number of log writes passed to a concrete log writer not vetoed by stream or "
-                              "filter policies.",
-                              "1", true)) {
+                              "filter policies.")) {
     rotations_pending = 0;
 }
 
@@ -947,7 +945,7 @@ bool Manager::Write(EnumVal* id, RecordVal* columns_arg) {
     if ( ! stream->total_writes ) {
         std::string module_name = zeek::detail::extract_module_name(stream->name.c_str());
         std::initializer_list<telemetry::LabelView> labels{{"module", module_name}, {"stream", stream->name}};
-        stream->total_writes = total_log_stream_writes_family.GetOrAdd(labels);
+        stream->total_writes = total_log_stream_writes_family->GetOrAdd(labels);
     }
 
     stream->total_writes->Inc();
@@ -1173,7 +1171,7 @@ bool Manager::WriteToFilters(const Manager::Stream* stream, zeek::RecordValPtr c
         }
 
         assert(w != stream->writers.end());
-        w->second->total_writes.Inc();
+        w->second->total_writes->Inc();
 
         // Write takes ownership of vals.
         assert(writer);
@@ -1616,7 +1614,7 @@ WriterFrontend* Manager::CreateWriter(EnumVal* id, EnumVal* writer, WriterBacken
                                                        {"filter-name", instantiating_filter},
                                                        {"path", info->path}};
 
-    WriterInfo* winfo = new WriterInfo(zeek::log_mgr->total_log_writer_writes_family.GetOrAdd(labels));
+    WriterInfo* winfo = new WriterInfo(zeek::log_mgr->total_log_writer_writes_family->GetOrAdd(labels));
     winfo->type = writer->Ref()->AsEnumVal();
     winfo->writer = nullptr;
     winfo->open_time = run_state::network_time;
